import React from 'react';
import { useLocation } from '@gatsbyjs/reach-router';
import PropTypes from 'prop-types';
// Pieces imports
import { GatsbyLink } from '../../GatsbyLink';
import { usePageContext } from '../../../utils/context';
import { useLocalizePath } from '../../../utils/hooks';

// Uses GatsbyLink, to navigate to a new page
export const PageLink = ({ children, to, sx = {}, variant = 'navigation' }) => {
  const location = useLocation();
  const { locale } = usePageContext();
  const localizedTo = useLocalizePath(to, locale);

  const isActive =
    location.pathname === localizedTo ||
    location.pathname === `${localizedTo}/`;
  return (
    <GatsbyLink active={isActive} sx={sx} to={localizedTo} variant={variant}>
      {children}
    </GatsbyLink>
  );
};

PageLink.propTypes = {
  to: PropTypes.string.isRequired,
  children: PropTypes.node.isRequired,
  sx: PropTypes.shape(),
  variant: PropTypes.string
};

PageLink.defaultProps = {
  sx: {},
  variant: 'navigation'
};
