import { useStaticQuery, graphql } from 'gatsby';
export const useSiteMetadata = () => {
  const data = useStaticQuery(
    graphql`
      query {
        favicon16: file(name: { eq: "favicon" }) {
          childImageSharp {
            resize(width: 16) {
              src
              width
              height
            }
          }
        }
        favicon32: file(name: { eq: "favicon" }) {
          childImageSharp {
            resize(width: 32) {
              src
              width
              height
            }
          }
        }
        favicon64: file(name: { eq: "favicon" }) {
          childImageSharp {
            resize(width: 64) {
              src
              width
              height
            }
          }
        }
        thumbnail: file(name: { eq: "thumbnail" }) {
          childImageSharp {
            gatsbyImageData(layout: FIXED, placeholder: BLURRED)
          }
        }
        site {
          siteMetadata {
            title
            description
            author
            url
            shortTitle
            shortDescription
            locales {
              default
              #     translations {
              #      code
              #     pathPrefix
              #     hreflang
              #    }
            }
            # translatedPaths {
            #   default
            #   deDE
            #  }
          }
        }
      }
    `
  );

  return {
    ...data.site.siteMetadata,
    thumbnail: data.thumbnail.childImageSharp.gatsbyImageData,
    favicon16: data.favicon16.childImageSharp.resize,
    favicon32: data.favicon32.childImageSharp.resize,
    favicon64: data.favicon64.childImageSharp.resize
  };
};
